# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: string_message.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14string_message.proto\"\x1d\n\rStringMessage\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\tb\x06proto3')



_STRINGMESSAGE = DESCRIPTOR.message_types_by_name['StringMessage']
StringMessage = _reflection.GeneratedProtocolMessageType('StringMessage', (_message.Message,), {
  'DESCRIPTOR' : _STRINGMESSAGE,
  '__module__' : 'string_message_pb2'
  # @@protoc_insertion_point(class_scope:StringMessage)
  })
_sym_db.RegisterMessage(StringMessage)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _STRINGMESSAGE._serialized_start=24
  _STRINGMESSAGE._serialized_end=53
# @@protoc_insertion_point(module_scope)
